@@ -98,18 +98,3 @@ check_directory_supports_executable_files() {
 	esac
 }
 
-# assert a variable is not empty and display an error message otherwise
-# USAGE: assert_not_empty $variable_name $calling_function
-assert_not_empty() {
-	local variable_name calling_function
-	variable_name="$1"
-	calling_function="$2"
-
-	local variable_value
-	variable_value=$(get_value "$variable_name")
-	if [ -z "$variable_value" ]; then
-		error_empty_string "$calling_function" "$variable_name"
-		return 1
-	fi
-}
-
