@@ -5,8 +5,8 @@ list_clean() {
 	## - remove leading and trailing spaces
 	## - sort the list and merge duplicate entries
 	## - remove empty lines, ignore errors on empty output
-	sed 's/^\s*//;s/\s*$//' | \
-		sort --unique | \
+	sed 's/^\s*//;s/\s*$//' |
+		sort --unique |
 		grep --invert-match --regexp='^$' || true
 }
 
