@@ -161,9 +161,9 @@ application_exe_escaped() {
 	printf '%s' "$application_exe" | sed "s/'/'\\\''/g"
 }
 
-# Print the full path to the application binary.
+# Print the full path to the application binary
+# An error is thrown if the binary file could not be found anywhere
 # USAGE: application_exe_path $application_exe
-# RETURN: the full path to the application binary
 application_exe_path() {
 	local application_exe
 	application_exe="$1"
@@ -184,6 +184,10 @@ application_exe_path() {
 	packages_list=$(packages_list)
 	for package in $packages_list; do
 		package_path=$(package_path "$package")
+		path_game_data=$(
+			set_current_package "$package"
+			path_game_data
+		)
 		application_exe_path="${package_path}${path_game_data}/${application_exe}"
 		if [ -f "$application_exe_path" ]; then
 			printf '%s' "$application_exe_path"
