@@ -114,7 +114,7 @@ archive_initialize_extra_parts() {
 			## Update the list of archives that are going to be used
 			archives_used_add "$archive_part"
 		else
-			error_archive_not_found "$archive_part_name"
+			error_archive_not_found "$archive_part"
 			return 1
 		fi
 	done
