@@ -11,6 +11,22 @@ archive_extraction_using_tar() {
 
 	local extractor_options archive_extraction_return_code
 	extractor_options=$(archive_extractor_options "$archive")
+	## Set default options based on archive type.
+	if [ -z "$extractor_options" ]; then
+		local archive_type
+		archive_type=$(archive_type "$archive")
+		case "$archive_type" in
+			('tar.bz2')
+				extractor_options='--bzip2'
+			;;
+			('tar.gz')
+				extractor_options='--gzip'
+			;;
+			('tar.xz')
+				extractor_options='--xz'
+			;;
+		esac
+	fi
 	printf 'tar --verbose %s --extract --file "%s" --directory "%s"\n' "$extractor_options" "$archive_path" "$destination_directory" >> "$log_file"
 	{
 		tar --verbose $extractor_options --extract --file "$archive_path" --directory "$destination_directory" >> "$log_file" 2>&1
