@@ -4,8 +4,7 @@ fake_home_enable() {
 	cat <<- 'EOF'
 	# Enable the fake $HOME
 	HOME_PATH_REAL="$HOME"
-	HOME_PATH_FAKE=$(fake_home_path)
-	export HOME="$HOME_PATH_FAKE"
+	export HOME="$PATH_FAKE_HOME"
 
 	EOF
 }
@@ -38,25 +37,12 @@ fake_home_persistent() {
 	cat <<- 'EOF'
 	# Divert paths from the fake $HOME to persistent storage
 
-	fake_home_path() {
-	    # Fake $HOME path can be explicitely set using an environment variable
-	    if [ -n "$PLAYIT_FAKE_HOME_PATH" ]; then
-	        printf '%s' "$PLAYIT_FAKE_HOME_PATH"
-	        return 0
-	    fi
-	    # Compute the default fake $HOME path if none has been explicitely set
-	    printf '%s/play.it/home/%s' \
-	        "${XDG_CACHE_HOME:="$HOME/.cache"}" \
-	        "$GAME_ID"
-	}
-	FAKE_HOME_PATH=$(fake_home_path)
-
 	## Divert paths set by the XDG Base Directory Specification
 	## cf. https://specifications.freedesktop.org/basedir-spec/basedir-spec-0.8.html
 	while read -r xdg_path_absolute; do
 	    if printf '%s' "$xdg_path_absolute" | grep --quiet --regexp="^${HOME}/"; then
 	        xdg_path_relative=$(printf '%s' "$xdg_path_absolute" | sed "s#^${HOME}/##")
-	        persistent_path_diversion "$FAKE_HOME_PATH" "$HOME" "$xdg_path_relative"
+	        persistent_path_diversion "$PATH_FAKE_HOME" "$HOME" "$xdg_path_relative"
 	    fi
 	done << EOL
 	${XDG_CACHE_HOME:-${HOME}/.cache}
@@ -76,7 +62,7 @@ fake_home_persistent() {
 	    if [ -z "$directory" ]; then
 	        continue
 	    fi
-	    persistent_path_diversion "$FAKE_HOME_PATH" "${USER_PERSISTENT_PATH}/fake-home" "$directory"
+	    persistent_path_diversion "$PATH_FAKE_HOME" "${PATH_PERSISTENT}/fake-home" "$directory"
 	done << EOL
 	$(printf '%s' "$FAKE_HOME_PERSISTENT_DIRECTORIES")
 	EOL
