@@ -1,3 +1,19 @@
+# Information: Launcher scripts and desktop entries are being written
+# USAGE: information_launchers_generation
+information_launchers_generation() {
+	local messages_language message
+	messages_language=$(messages_language)
+	case "$messages_language" in
+		('fr')
+			message='Génération des lanceurs…\n'
+		;;
+		('en'|*)
+			message='Launchers generation…\n'
+		;;
+	esac
+	print_message 'info_once' "$message"
+}
+
 # Error - A binary file is missing
 # USAGE: error_launcher_missing_binary $binary
 # CALLS: print_error
