@@ -68,9 +68,9 @@ dependencies_unknown_gstreamer_media_formats_add() {
 	unknown_formats_list=$(dependencies_unknown_gstreamer_media_formats_file)
 
 	# Do nothing if this format is already included in the list
-	if \
-		[ -e "$unknown_formats_list" ] \
-		&& grep --quiet --fixed-strings --word-regexp "$unknown_format" "$unknown_formats_list"
+	if
+		[ -e "$unknown_formats_list" ] &&
+		grep --quiet --fixed-strings --word-regexp "$unknown_format" "$unknown_formats_list"
 	then
 		return 0
 	fi
