@@ -89,9 +89,9 @@ dependencies_unknown_mono_libraries_add() {
 	unknown_libraries_list=$(dependencies_unknown_mono_libraries_file)
 
 	# Do nothing if this library is already included in the list
-	if \
-		[ -e "$unknown_libraries_list" ] \
-		&& grep --quiet --fixed-strings --word-regexp "$unknown_library" "$unknown_libraries_list"
+	if
+		[ -e "$unknown_libraries_list" ] &&
+		grep --quiet --fixed-strings --word-regexp "$unknown_library" "$unknown_libraries_list"
 	then
 		return 0
 	fi
