@@ -1,6 +1,6 @@
 # Print the list of sibling packages required by a given package
 # USAGE: dependencies_list_siblings $package
-# RETURNS: a list of package identifiers,
+# RETURNS: a list of package names,
 #          one per line
 dependencies_list_siblings() {
 	local package
@@ -25,6 +25,13 @@ dependencies_list_siblings() {
 		return 0
 	fi
 
-	printf '%s' "$dependencies_siblings" | list_clean
+	# Convert the package identifiers to full package names
+	local sibling
+	while read -r sibling; do
+		package_id "$sibling"
+		printf '\n'
+	done <<- EOL
+	$(printf '%s' "$dependencies_siblings" | list_clean)
+	EOL
 }
 
