@@ -162,6 +162,11 @@ path_libraries_system() {
 		;;
 	esac
 
+	if [ -z "${path_libraries:-}" ]; then
+		error_path_libraries_system_unsupported_architecture "$current_package"
+		return 1
+	fi
+
 	printf '%s' "$path_libraries"
 }
 
