@@ -4,8 +4,9 @@ error_dosbox_disk_image_no_found() {
 	local disk_image
 	disk_image="$1"
 
-	local message
-	case "${LANG%_*}" in
+	local messages_language message
+	messages_language=$(messages_language)
+	case "$messages_language" in
 		('fr')
 			message='Lʼimage de disque suivante nʼa pas été trouvée : %s\n'
 		;;
