@@ -9,10 +9,14 @@ mono_launcher() {
 	case "$prefix_type" in
 		('symlinks')
 			launcher_headers
+
+			# Set the paths that should be available to the generated launcher
+			launcher_init_paths "$application"
+
 			mono_launcher_environment "$application"
 
 			# Generate the game prefix
-			launcher_prefix_symlinks_functions
+			prefix_generate_links_farm
 			launcher_prefix_symlinks_build
 
 			# Set up the paths diversion to persistent storage
@@ -31,6 +35,10 @@ mono_launcher() {
 		;;
 		('none')
 			launcher_headers
+
+			# Set the paths that should be available to the generated launcher
+			launcher_init_paths "$application"
+
 			mono_launcher_environment "$application"
 			mono_launcher_run "$application"
 			launcher_exit
@@ -48,16 +56,12 @@ mono_launcher_environment() {
 	local application
 	application="$1"
 
-	local game_id path_game application_exe
-	game_id=$(game_id)
-	path_game=$(path_game_data)
+	local application_exe
 	application_exe=$(application_exe_escaped "$application")
 
 	cat <<- EOF
 	# Set the environment
 
-	GAME_ID='$game_id'
-	PATH_GAME='$path_game'
 	APP_EXE='$application_exe'
 
 	EOF
@@ -76,7 +80,7 @@ mono_launcher_run() {
 			execution_path='$PATH_PREFIX'
 		;;
 		('none')
-			execution_path='$PATH_GAME'
+			execution_path='$PATH_GAME_DATA'
 		;;
 	esac
 	cat <<- EOF
@@ -86,8 +90,12 @@ mono_launcher_run() {
 
 	EOF
 
-	# Set loading paths for libraries
-	native_launcher_libraries
+	# Set the preload paths for native libraries
+	cat <<- 'EOF'
+	## Set the preload paths for native libraries
+	export LD_LIBRARY_PATH="${PATH_LIBRARIES_USER}:${PATH_LIBRARIES_SYSTEM}:${LD_LIBRARY_PATH:-}"
+
+	EOF
 
 	application_prerun "$application"
 
