@@ -19,7 +19,7 @@ application_scummvm_scummid() {
 	# - "engine:game"
 	# - "game"
 	# The game field is allowed to include hyphen-minus, like in: "ags:gobliiins5-1"
-	if ! printf '%s' "$application_scummid" | \
+	if ! printf '%s' "$application_scummid" |
 		grep --quiet --regexp='^\([0-9a-z]\+:\)\?[-0-9a-z]\+$'
 	then
 		error_application_scummid_invalid "$application" "$application_scummid"
