@@ -5,8 +5,9 @@ error_application_scummid_invalid() {
 	application="$1"
 	application_scummid="$2"
 
-	local message
-	case "${LANG%_*}" in
+	local messages_language message
+	messages_language=$(messages_language)
+	case "$messages_language" in
 		('fr')
 			message='Lʼid ScummVM fourni pour lʼapplication %s ne semble pas correct : "%s"\n'
 			message="$message"'Une liste de valeurs acceptées peut se trouver sur le site Web de ScummVM : \n%s\n'
