@@ -12,12 +12,13 @@ wine_wineprefix_tweaks() {
 # USAGE: wine_wineprefix_tweak_mono_install
 # RETURN: the code snippet, for inclusion in the game launcher script
 wine_wineprefix_tweak_mono_install() {
-	local mono_installer_name
+	local game_id mono_installer_name
+	game_id=$(game_id)
 	mono_installer_name=$(archive_name 'ARCHIVE_MONO')
 	{
 		cat <<- EOF
 		    ## Install Mono in the WINE prefix.
-		    \$(wine_command) "\${WINEPREFIX}/drive_c/\${GAME_ID}/wineprefix-tweaks/${mono_installer_name}"
+		    \$(wine_command) "\${WINEPREFIX}/drive_c/${game_id}/wineprefix-tweaks/${mono_installer_name}"
 
 		EOF
 	}
