@@ -65,7 +65,8 @@ content_inclusion_unity3d_plugins() {
 
 		# Delete the remaining plugins for the current architecture,
 		# to prevent them from being included later.
-		rm --force "${plugins_path}/${architecture_string}"/*
+		find "${plugins_path}/${architecture_string}" -mindepth 1 -type f -delete
+		find "${plugins_path}/${architecture_string}" -mindepth 1 -type d -empty -delete
 		rmdir --ignore-fail-on-non-empty --parents "${plugins_path}/${architecture_string}"
 	fi
 
@@ -78,7 +79,8 @@ content_inclusion_unity3d_plugins() {
 		# shellcheck disable=SC2034
 		CONTENT_UNITY3D_PLUGINS_PATH="$plugins_directory"
 		content_inclusion 'UNITY3D_PLUGINS' "$package" "$target_directory"
-		rm --force "$plugins_path"/*.*
+		find "$plugins_path" -mindepth 1 -type f -delete
+		find "$plugins_path" -mindepth 1 -type d -empty -delete
 		rmdir --ignore-fail-on-non-empty --parents "$plugins_path"
 	fi
 }
