@@ -1,8 +1,9 @@
 # Error - Unity3D - No binary has been found
 # USAGE: error_unity3d_binary_not_found
 error_unity3d_binary_not_found() {
-	local message
-	case "${LANG%_*}" in
+	local messages_language message
+	messages_language=$(messages_language)
+	case "$messages_language" in
 		('fr')
 			message='Aucun exécutable nʼa été trouvé pour ce jeu Unity3D.\n'
 			message="$message"'Cette erreur est probablement due à une valeur incorrecte assignée à CONTENT_PATH_DEFAULT.\n'
