@@ -24,7 +24,8 @@ visionaire_application_exe() {
 		if [ -z "$filename_candidate" ]; then
 			continue
 		fi
-		filename_path=$(application_exe_path "$filename_candidate")
+		## Do not throw an error if no path is found for the current candidate.
+		filename_path=$(application_exe_path "$filename_candidate") 2>/dev/null || true
 		if [ -n "$filename_path" ]; then
 			application_exe="$filename_candidate"
 			break
