@@ -60,6 +60,10 @@ archlinux_dependencies_single_command() {
 			package_names='
 			jre8-openjdk'
 		;;
+		('julius')
+			package_names='
+			julius'
+		;;
 		('mono')
 			package_names='
 			mono'
