@@ -115,6 +115,9 @@ dependency_package_providing_library_arch() {
 		('libcrypt.so.1')
 			package_name='libxcrypt'
 		;;
+		('libcrypto.so.3')
+			package_name='openssl'
+		;;
 		('libcups.so.2')
 			package_name='libcups'
 		;;
@@ -421,6 +424,9 @@ dependency_package_providing_library_arch() {
 		('libssl.so.1.0.0')
 			package_name='openssl-1.0'
 		;;
+		('libssl.so.3')
+			package_name='openssl'
+		;;
 		('libssl.so.1.1')
 			package_name='openssl-1.1'
 		;;
@@ -659,6 +665,9 @@ dependency_package_providing_library_arch32() {
 		('libcrypt.so.1')
 			package_name='lib32-libxcrypt'
 		;;
+		('libcrypto.so.3')
+			package_name='lib32-openssl'
+		;;
 		('libcups.so.2')
 			package_name='lib32-libcups'
 		;;
@@ -975,6 +984,9 @@ dependency_package_providing_library_arch32() {
 		('libssl.so.1.1')
 			package_name='lib32-openssl-1.1'
 		;;
+		('libssl.so.3')
+			package_name='lib32-openssl'
+		;;
 		('libssl3.so')
 			package_name='lib32-nss'
 		;;
