@@ -7,8 +7,9 @@ info_package_mtree_computation() {
 	local package_path
 	package_path=$(package_path "$package")
 
-	local message
-	case "${LANG%_*}" in
+	local messages_language message
+	messages_language=$(messages_language)
+	case "$messages_language" in
 		('fr')
 			message='Création du fichier .MTREE pour %s…\n'
 		;;
