@@ -98,6 +98,9 @@ dependency_package_providing_library_deb() {
 		('libcrypt.so.1')
 			package_name='libcrypt1'
 		;;
+		('libcrypto.so.3')
+			package_name='libssl3'
+		;;
 		('libcups.so.2')
 			package_name='libcups2'
 		;;
@@ -418,6 +421,9 @@ dependency_package_providing_library_deb() {
 			# https://downloads.dotslashplay.it/resources/openssl/
 			return 0
 		;;
+		('libssl.so.3')
+			package_name='libssl3'
+		;;
 		('libssl3.so')
 			package_name='libnss3'
 		;;
