@@ -153,7 +153,7 @@ dependencies_gentoo_full_list() {
 	option_package=$(option_value 'package')
 	case "$option_package" in
 		('gentoo')
-			packages_list=$(gentoo_dependencies_siblings "$package")
+			packages_list=$(dependencies_list_siblings "$package")
 			packages_list_full="$packages_list_full
 			$packages_list"
 		;;
