@@ -126,6 +126,9 @@ dependency_package_providing_library_gentoo() {
 		('libcrypt.so.1')
 			package_name='sys-libs/libxcrypt'
 		;;
+		('libcrypto.so.3')
+			package_name='dev-libs/openssl'
+		;;
 		('libcups.so.2')
 			package_name='net-print/cups'
 		;;
@@ -445,6 +448,9 @@ dependency_package_providing_library_gentoo() {
 		('libssl.so.1.1')
 			package_name='dev-libs/openssl-compat:1.1.1'
 		;;
+		('libssl.so.3')
+			package_name='dev-libs/openssl'
+		;;
 		('libssl3.so')
 			package_name='dev-libs/nss'
 		;;
@@ -681,6 +687,9 @@ dependency_package_providing_library_gentoo32() {
 		('libcrypt.so.1')
 			package_name='sys-libs/libxcrypt[abi_x86_32]'
 		;;
+		('libcrypto.so.3')
+			package_name='dev-libs/openssl[abi_x86_32]'
+		;;
 		('libcups.so.2')
 			package_name='net-print/cups[abi_x86_32]'
 		;;
@@ -1000,6 +1009,9 @@ dependency_package_providing_library_gentoo32() {
 		('libssl.so.1.1')
 			package_name='dev-libs/openssl-compat:1.1.1[abi_x86_32]'
 		;;
+		('libssl.so.3')
+			package_name='dev-libs/openssl[abi_x86_32]'
+		;;
 		('libssl3.so')
 			package_name='dev-libs/nss[abi_x86_32]'
 		;;
