@@ -1,7 +1,7 @@
 # Check for the presence of required tools
 # USAGE: init_requirements_check
 init_requirements_check() {
-	if ! check_deps; then
+	if ! requirements_check; then
 		# Delete temporary files
 		working_directory_cleanup
 
