@@ -1,4 +1,5 @@
 #!/bin/sh
+set -o nounset
 
 oneTimeSetUp() {
 	# Load the ./play.it library
@@ -37,7 +38,7 @@ test_content_path() {
 		PLAYIT_CONTEXT_ARCHIVE
 
 	CONTENT_PATH_DEFAULT='default/path'
-	assertEquals "$CONTENT_PATH_DEFAULT" "$(content_path)"
+	assertEquals "$CONTENT_PATH_DEFAULT" "$(content_path 'GAME_DATA')"
 
 	CONTENT_GAME_DATA_PATH='specific/path'
 	assertEquals "$CONTENT_GAME_DATA_PATH" "$(content_path 'GAME_DATA')"
